# EyesonAPI
An EyesonAPI module - work in progress

We try to create 
- an SDK for Python including all functionalities possible in one module and
- additional helper tools.

## Links
- Eyeson API documentation https://docs.eyeson.com/docs/rest/intro
- Eyeson API technical info https://www.eyeson.com/eyeson-video-call-api-overview
